@@ -8,7 +8,6 @@ import types
 from funcparserlib.parser import NoParseError, many
 
 import hy
-from hy._compat import PY3_8
 from hy.errors import HyCompileError, HyLanguageError, HySyntaxError
 from hy.macros import macroexpand
 from hy.model_patterns import FORM, KEYWORD, unpack
@@ -359,8 +358,8 @@ class HyASTCompiler:
 
         # Hy expects this to be present, so we prep the module for Hy
         # compilation.
-        self.module.__dict__.setdefault("__macros__", {})
-        self.module.__dict__.setdefault("__reader_macros__", {})
+        self.module.__dict__.setdefault("_hy_macros", {})
+        self.module.__dict__.setdefault("_hy_reader_macros", {})
 
         self.scope = ScopeGlobal(self)
 
@@ -580,17 +579,13 @@ class HyASTCompiler:
 
     @builds_model(Integer, Float, Complex)
     def compile_numeric_literal(self, x):
-        f = {Integer: int, Float: float, Complex: complex}[type(x)]
-        return asty.Num(x, n=f(x))
+        return asty.Constant(x, value =
+            {Integer: int, Float: float, Complex: complex}[type(x)](x))
 
     @builds_model(Symbol)
     def compile_symbol(self, symbol):
         if symbol == Symbol("..."):
-            return (
-                asty.Constant(symbol, value=Ellipsis)
-                if PY3_8
-                else asty.Ellipsis(symbol)
-            )
+            return asty.Constant(symbol, value=Ellipsis)
 
         # By this point, `symbol` should be either all dots or
         # dot-free.
@@ -617,16 +612,15 @@ class HyASTCompiler:
                 attr="Keyword",
                 ctx=ast.Load(),
             ),
-            args=[asty.Str(obj, s=obj.name)],
+            args=[asty.Constant(obj, value=obj.name)],
             keywords=[],
         )
         return ret
 
     @builds_model(String, Bytes)
     def compile_string(self, string):
-        node = asty.Bytes if type(string) is Bytes else asty.Str
-        f = bytes if type(string) is Bytes else str
-        return node(string, s=f(string))
+        return asty.Constant(string, value =
+            (bytes if type(string) is Bytes else str)(string))
 
     @builds_model(FComponent)
     def compile_fcomponent(self, fcomponent):
@@ -861,7 +855,8 @@ def hy_compile(
         if (
             result.stmts
             and isinstance(result.stmts[0], ast.Expr)
-            and isinstance(result.stmts[0].value, ast.Str)
+            and isinstance(result.stmts[0].value, ast.Constant)
+            and isinstance(result.stmts[0].value.value, str)
         ):
 
             body += [result.stmts.pop(0)]
