@@ -15,7 +15,7 @@ from itertools import dropwhile
 
 from funcparserlib.parser import finished, forward_decl, many, maybe, oneplus, some
 
-from hy._compat import PY3_11
+from hy._compat import PY3_11, PY3_12
 from hy.compiler import Result, asty, hy_eval, mkexpr
 from hy.errors import HyEvalError, HyInternalError, HyTypeError
 from hy.macros import pattern_macro, require, require_reader
@@ -131,7 +131,7 @@ def compile_inline_python(compiler, expr, root, code):
     try:
         o = asty.parse(
             expr,
-            textwrap.dedent(code) if exec_mode else code,
+            textwrap.dedent(code) if exec_mode else "(" + code + "\n)",
             compiler.filename,
             "exec" if exec_mode else "eval",
         ).body
@@ -354,7 +354,7 @@ m_ops = {
 def compile_maths_expression(compiler, expr, root, args):
     if len(args) == 0:
         # Return the identity element for this operator.
-        return asty.Num(expr, n=({"+": 0, "|": 0, "*": 1}[root]))
+        return asty.Constant(expr, value=({"+": 0, "|": 0, "*": 1}[root]))
 
     if len(args) == 1:
         if root == "/":
@@ -486,8 +486,11 @@ def compile_assign(
     return result
 
 
-@pattern_macro(["global", "nonlocal"], [oneplus(SYM)])
+@pattern_macro(["global", "nonlocal"], [many(SYM)])
 def compile_global_or_nonlocal(compiler, expr, root, syms):
+    if not syms:
+        return asty.Pass(expr)
+
     node = asty.Global if root == "global" else asty.Nonlocal
     ret = node(expr, names=[mangle(s) for s in syms])
 
@@ -893,6 +896,7 @@ def compile_comprehension(compiler, expr, root, parts, final):
                 ),
                 body=stmts + f(parts).stmts,
                 decorator_list=[],
+                **({"type_params": []} if PY3_12 else {}),
             )
             # Immediately call the new function. Unless the user asked
             # for a generator, wrap the call in `[].__class__(...)` or
@@ -1131,6 +1135,7 @@ def compile_match_expression(compiler, expr, root, subject, clauses):
                     ),
                     body=guard.stmts + [asty.Return(guard.expr, value=guard.expr)],
                     decorator_list=[],
+                    **({"type_params": []} if PY3_12 else {}),
                 )
                 lifted_if_defs.append(guardret)
                 guard = Result(expr=asty.parse(guard, f"{fname}()").body[0].value)
@@ -1287,7 +1292,16 @@ def compile_raise_expression(compiler, expr, root, exc, cause):
     ],
 )
 def compile_try_expression(compiler, expr, root, body, catchers, orelse, finalbody):
+    if orelse is not None and not catchers:
+        # Python forbids `else` when there are no `except` clauses.
+        # But we can get the same effect by appending the `else` forms
+        # to the body.
+        body += list(orelse)
+        orelse = None
     body = compiler._compile_branch(body)
+    if not (catchers or finalbody):
+        # Python forbids this, so just return the body, per `do`.
+        return body
 
     return_var = asty.Name(expr, id=mangle(compiler.get_anon_var()), ctx=ast.Store())
 
@@ -1362,15 +1376,6 @@ def compile_try_expression(compiler, expr, root, body, catchers, orelse, finalbo
         finalbody += finalbody.expr_as_stmt()
         finalbody = finalbody.stmts
 
-    # Using (else) without (except) is verboten!
-    if orelse and not handlers:
-        raise compiler._syntax_error(expr, "`try' cannot have `else' without `except'")
-    # Likewise a bare (try) or (try BODY).
-    if not (handlers or finalbody):
-        raise compiler._syntax_error(
-            expr, "`try' must have an `except' or `finally' clause"
-        )
-
     returnable = Result(
         expr=asty.Name(expr, id=return_var.id, ctx=ast.Load()),
         temp_variables=[return_var],
@@ -1463,6 +1468,7 @@ def compile_function_node(compiler, expr, node, decorators, name, args, returns,
         body=body.stmts or [asty.Pass(expr)],
         decorator_list=decorators,
         returns=compiler.compile(returns).force_expr if returns is not None else None,
+        **({"type_params": []} if PY3_12 else {}),
     )
 
     ast_name = asty.Name(expr, id=name, ctx=ast.Load())
@@ -1676,6 +1682,7 @@ def compile_class_expression(compiler, expr, root, decorators, name, rest):
         kwargs=None,
         bases=bases_expr,
         body=bodyr.stmts or [asty.Pass(expr)],
+        **({"type_params": []} if PY3_12 else {}),
     )
 
 
@@ -1776,6 +1783,8 @@ def compile_require(compiler, expr, root, entries):
                         dotted("hy.macros.require"),
                         String(module_name),
                         Symbol("None"),
+                        Keyword("target_module_name"),
+                        String(compiler.module.__name__),
                         Keyword("assignments"),
                         (
                             String("EXPORTS")
@@ -1793,7 +1802,7 @@ def compile_require(compiler, expr, root, entries):
             reader_assignments = (
                 "ALL"
                 if readers == Symbol("*")
-                else ["#" + reader for reader in readers[0]]
+                else [str(reader) for reader in readers[0]]
             )
             if require_reader(module_name, compiler.module, reader_assignments):
                 ret += compiler.compile(
