@@ -1,21 +1,14 @@
-# -*- encoding: utf-8 -*-
-# Copyright 2020 the authors.
-# This file is part of Hy, which is free software licensed under the Expat
-# license. See the LICENSE.
 import os
 import re
 import sys
 import traceback
-import pkgutil
-
-from functools import reduce
-from colorama import Fore
+import importlib.util
 from contextlib import contextmanager
-from hy import _initialize_env_var
 
-_hy_filter_internal_errors = _initialize_env_var('HY_FILTER_INTERNAL_ERRORS',
-                                                 True)
-COLORED = _initialize_env_var('HY_COLORED_ERRORS', False)
+from hy import _initialize_env_var
+from hy._compat import PYPY
+
+_hy_filter_internal_errors = _initialize_env_var("HY_FILTER_INTERNAL_ERRORS", True)
 
 
 class HyError(Exception):
@@ -36,56 +29,54 @@ class HyLanguageError(HyError):
     This, and any errors inheriting from this, are user-facing.
     """
 
-    def __init__(self, message, expression=None, filename=None, source=None,
-                 lineno=1, colno=1):
+    def __init__(
+        self,
+        message,
+        expression=None,
+        filename=None,
+        source=None,
+        lineno=1,
+        colno=1,
+    ):
         """
-        Parameters
-        ----------
-        message: str
-            The message to display for this error.
-        expression: HyObject, optional
-            The Hy expression generating this error.
-        filename: str, optional
-            The filename for the source code generating this error.
-            Expression-provided information will take precedence of this value.
-        source: str, optional
-            The actual source code generating this error.  Expression-provided
-            information will take precedence of this value.
-        lineno: int, optional
-            The line number of the error.  Expression-provided information will
-            take precedence of this value.
-        colno: int, optional
-            The column number of the error.  Expression-provided information
-            will take precedence of this value.
+        Args:
+            message (str): The message to display for this error.
+            expression (Optional[Object]): The Hy expression generating this error.
+            filename (Optional[str]): The filename for the source code generating this error.
+                Expression-provided information will take precedence of this value. Defaults to `None`.
+            source (Optional[str]): The actual source code generating this error.  Expression-provided
+                information will take precedence of this value. Defaults to `None`.
+            lineno (int): The line number of the error.  Expression-provided information will
+                take precedence of this value. Defaults to `1`.
+            colno (int): The column number of the error.  Expression-provided information
+                will take precedence of this value. Defaults to `1`.
         """
         self.msg = message
         self.compute_lineinfo(expression, filename, source, lineno, colno)
 
         if isinstance(self, SyntaxError):
-            syntax_error_args = (self.filename, self.lineno, self.offset,
-                                 self.text)
-            super(HyLanguageError, self).__init__(message, syntax_error_args)
+            syntax_error_args = (self.filename, self.lineno, self.offset, self.text)
+            super().__init__(message, syntax_error_args)
         else:
-            super(HyLanguageError, self).__init__(message)
+            super().__init__(message)
 
     def compute_lineinfo(self, expression, filename, source, lineno, colno):
 
         # NOTE: We use `SyntaxError`'s field names (i.e. `text`, `offset`,
         # `msg`) for compatibility and print-outs.
-        self.text = getattr(expression, 'source', source)
-        self.filename = getattr(expression, 'filename', filename)
+        self.text = getattr(expression, "source", source)
+        self.filename = getattr(expression, "filename", filename)
 
         if self.text:
             lines = self.text.splitlines()
 
-            self.lineno = getattr(expression, 'start_line', lineno)
-            self.offset = getattr(expression, 'start_column', colno)
-            end_column = getattr(expression, 'end_column',
-                                 len(lines[self.lineno-1]))
-            end_line = getattr(expression, 'end_line', self.lineno)
+            self.lineno = getattr(expression, "start_line", lineno)
+            self.offset = getattr(expression, "start_column", colno)
+            end_column = getattr(expression, "end_column", len(lines[self.lineno - 1]))
+            end_line = getattr(expression, "end_line", self.lineno)
 
             # Trim the source down to the essentials.
-            self.text = '\n'.join(lines[self.lineno-1:end_line])
+            self.text = "\n".join(lines[self.lineno - 1 : end_line])
 
             if end_column:
                 if self.lineno == end_line:
@@ -110,49 +101,41 @@ class HyLanguageError(HyError):
         # Syntax errors are special and annotate the traceback (instead of what
         # we would do in the message that follows the traceback).
         if isinstance(self, SyntaxError):
-            return super(HyLanguageError, self).__str__()
+            return super().__str__()
         # When there isn't extra source information, use the normal message.
         elif not self.text:
-            return super(HyLanguageError, self).__str__()
+            return super().__str__()
 
         # Re-purpose Python's builtin syntax error formatting.
         output = traceback.format_exception_only(
             SyntaxError,
-            SyntaxError(self.msg, (self.filename, self.lineno, self.offset,
-                                   self.text)))
+            SyntaxError(self.msg, (self.filename, self.lineno, self.offset, self.text)),
+        )
 
-        arrow_idx, _ = next(((i, x) for i, x in enumerate(output)
-                             if x.strip() == '^'),
-                            (None, None))
+        arrow_idx, _ = next(
+            ((i, x) for i, x in enumerate(output) if x.strip() == "^"), (None, None)
+        )
         if arrow_idx:
             msg_idx = arrow_idx + 1
         else:
-            msg_idx, _ = next((i, x) for i, x in enumerate(output)
-                              if x.startswith('SyntaxError: '))
+            msg_idx, _ = next(
+                (i, x) for i, x in enumerate(output) if x.startswith("SyntaxError: ")
+            )
 
         # Get rid of erroneous error-type label.
-        output[msg_idx] = re.sub('^SyntaxError: ', '', output[msg_idx])
+        output[msg_idx] = re.sub("^SyntaxError: ", "", output[msg_idx])
 
         # Extend the text arrow, when given enough source info.
         if arrow_idx and self.arrow_offset:
-            output[arrow_idx] = '{}{}^\n'.format(output[arrow_idx].rstrip('\n'),
-                                                 '-' * (self.arrow_offset - 1))
-
-        if COLORED:
-            output[msg_idx:] = [Fore.YELLOW + o + Fore.RESET for o in output[msg_idx:]]
-            if arrow_idx:
-                output[arrow_idx] = Fore.GREEN + output[arrow_idx] + Fore.RESET
-            for idx, line in enumerate(output[::msg_idx]):
-                if line.strip().startswith(
-                        'File "{}", line'.format(self.filename)):
-                    output[idx] = Fore.RED + line + Fore.RESET
+            output[arrow_idx] = "{}{}^\n".format(
+                output[arrow_idx].rstrip("\n"), "-" * (self.arrow_offset - 1)
+            )
 
         # This resulting string will come after a "<class-name>:" prompt, so
         # put it down a line.
-        output.insert(0, '\n')
+        output.insert(0, "\n")
 
-        # Avoid "...expected str instance, ColoredString found"
-        return reduce(lambda x, y: x + y, output)
+        return "".join(output)
 
 
 class HyCompileError(HyInternalError):
@@ -193,7 +176,7 @@ class HyEvalError(HyLanguageError):
 
 
 class HyIOError(HyInternalError, IOError):
-    """ Subclass used to distinguish between IOErrors raised by Hy itself as
+    """Subclass used to distinguish between IOErrors raised by Hy itself as
     opposed to Hy programs.
     """
 
@@ -213,7 +196,11 @@ class HyWrapperError(HyError, TypeError):
 
 def _module_filter_name(module_name):
     try:
-        compiler_loader = pkgutil.get_loader(module_name)
+        spec = importlib.util.find_spec(module_name)
+        if not spec:
+            return None
+
+        compiler_loader = spec.loader
         if not compiler_loader:
             return None
 
@@ -228,18 +215,37 @@ def _module_filter_name(module_name):
         else:
             # Normalize filename endings, because tracebacks will use `pyc` when
             # the loader says `py`.
-            return filename.replace('.pyc', '.py')
+            return filename.replace(".pyc", ".py")
     except Exception:
         return None
 
 
-_tb_hidden_modules = {m for m in map(_module_filter_name,
-                                     ['hy.compiler', 'hy.lex',
-                                      'hy.cmdline', 'hy.lex.parser',
-                                      'hy.importer', 'hy._compat',
-                                      'hy.macros', 'hy.models',
-                                      'rply'])
-                      if m is not None}
+_tb_hidden_modules = {
+    m
+    for m in map(
+        _module_filter_name,
+        [
+            "hy.compiler",
+            "hy.reader",
+            "hy.cmdline",
+            "hy.repl",
+            "hy.reader.parser",
+            "hy.importer",
+            "hy._compat",
+            "hy.macros",
+            "hy.models",
+            "hy.core.result_macros",
+        ],
+    )
+    if m is not None
+}
+
+# We can't derive these easily from just their module names due
+# to missing magic attributes in internal importlib modules
+_tb_hidden_modules.update(
+    f"<builtin>/frozen {x}" if PYPY else f"<frozen {x}>"
+    for x in ("importlib._bootstrap", "importlib._bootstrap_external")
+)
 
 
 def hy_exc_filter(exc_type, exc_value, exc_traceback):
@@ -255,8 +261,11 @@ def hy_exc_filter(exc_type, exc_value, exc_traceback):
     # frame = (filename, line number, function name*, text)
     new_tb = []
     for frame in traceback.extract_tb(exc_traceback):
-        if not (frame[0].replace('.pyc', '.py') in _tb_hidden_modules or
-                os.path.dirname(frame[0]) in _tb_hidden_modules):
+        if not (
+            frame[0].replace(".pyc", ".py") in _tb_hidden_modules
+            or os.path.dirname(frame[0]) in _tb_hidden_modules
+            or os.path.basename(os.path.dirname(frame[0])) == "hy.exe"
+        ):
             new_tb += [frame]
 
     lines = traceback.format_list(new_tb)
@@ -264,7 +273,7 @@ def hy_exc_filter(exc_type, exc_value, exc_traceback):
     lines.insert(0, "Traceback (most recent call last):\n")
 
     lines.extend(traceback.format_exception_only(exc_type, exc_value))
-    output = ''.join(lines)
+    output = "".join(lines)
 
     return output
 
@@ -273,7 +282,7 @@ def hy_exc_handler(exc_type, exc_value, exc_traceback):
     """A `sys.excepthook` handler that uses `hy_exc_filter` to
     remove internal Hy frames from a traceback print-out.
     """
-    if os.environ.get('HY_DEBUG', False):
+    if os.environ.get("HY_DEBUG", False):
         return sys.__excepthook__(exc_type, exc_value, exc_traceback)
 
     try:
